# -*- coding: utf-8 -*-
import datetime
import time


def day_week():
    """
    Получить порядковый номер дня недели

    :rtype int
    :return: Число 1, 2, 3, 4, 5, 6, 7
    """
    return datetime.datetime.today().isoweekday()


def now_eng(hms=False):
    """
    Дата и время в английском формате

    :rtype: str
    :return: Образец: 03.01.2021 11:32:47
    """
    pattern = "%Y-%m-%d %H:%M:%S" if hms else "%Y-%m-%d"
    return now().strftime(pattern)


def now_rus(hms=False):
    """
    Дата и время в русском формате

    :rtype: str
    :return: Образец: 03.01.2021 11:32:47
    """
    pattern = "%d.%m.%Y %H:%M:%S" if hms else "%d.%m.%Y"
    return now().strftime(pattern)


def now():
    """
    Получить текущие дату и время

    :rtype: datetime.datetime
    :return: Образец: 2021-01-03 11:22:25.248840
    """
    return datetime.datetime.now()


def unix():
    """
    Получить UNIX-метку

    :rtype: int
    :return: Количество секунд, прошедших с 1 января 1970 года
    """
    return int(time.time())



# -*- coding: utf-8 -*-
import csv


def diff(list_one, list_two):
    """
    Вычесть из первого списка элементы второго списка

    :param list_one:
    :type list_one: list
    :param list_two:
    :type list_two: list

    :rtype list
    :return: Элементы 1-го списка, которых нет во 2-м списке
    """
    return list(set(list_one) - set(list_two))


def intersect(list_one, list_two):
    """
    Найти элементы присутствующие в обоих списках

    :param list_one:
    :type list_one: list
    :param list_two:
    :type list_two: list

    :rtype list
    :return: Общие для двух списков элементы
    """
    return [x for x in list_one if x in list_two]



# -*- coding: utf-8 -*-
import re


def clear_html(html):
    """
    Очистить строку от всех html-тегов

    :param html:
    :type html: str

    :rtype str
    :return: Строка без html
    """
    regex = re.compile(r'<.*?>', re.DOTALL)
    return regex.sub('', html)


def all_chars(txt, ru=True):
    """
    Получить все символы из текста (кириллица или латиница)

    :param txt: строка
    :type txt: str

    :rtype: list
    :return: Список: ['йцу', 'фыв', 'ячс'] / ['qwe', 'asd', 'zxc']
    """
    regex_char = re.compile('[а-яА-яёЁ]+') if ru else re.compile('[a-zA-Z]+')
    return regex_char.findall(txt)


def all_num(txt):
    """
    Получить все цифры из текста

    :param txt: строка
    :type txt: str

    :rtype: list
    :return: Список: ['123', '456', '789']
    """
    regex_num = re.compile('\d+')
    return regex_num.findall(txt)



# -*- coding: utf-8 -*-
import csv


def csv_sort(reader, column_id, desc=True):
    """
    Отсортировать csv-файл по определенной колонке

    :param reader:
    :param column_id:
    :param desc:

    :return:
    """
    return sorted(reader, key=lambda row: row[column_id], reverse=desc)


def csv_write(f_name, row, mode='a'):
    """
    Записать одну строку в csv-файл

    :param f_name: Путь к файлу
    :type f_name: str
    :param row: Список
    :type row: list
    :param mode: Режим работы с файлом
    :type mode: str

    :rtype None
    :return: Запись в файл
    """
    with open(f_name, mode, newline='', encoding="utf8") as csv_file:
        writer = csv.writer(csv_file, delimiter=',')
        writer.writerow(row)


def csv_write_rows(f_name, rows, mode='a'):
    """
    Записать несколько строк в csv-файл

    :param f_name: Путь к файлу
    :type f_name: str
    :param rows: Список списков
    :type rows: list
    :param mode: Режим работы с файлом
    :type mode: str

    :rtype None
    :return: Запись в файл
    """
    with open(f_name, mode, newline='', encoding="utf8") as csv_file:
        writer = csv.writer(csv_file, delimiter=',')
        writer.writerows(rows)



# -*- coding: utf-8 -*-
import os
import glob


def listdir(directory, deep=False, mask='**/*'):
    """
    Получить все файлы из директории (рекурсивно или нет)

    :param directory: целевая директория
    :type directory: str
    :param deep: рекурсивно или нет
    :type deep: bool
    :param mask: маска поиска ('**/*', '**/*.txt', etc)
    :type mask: str

    :rtype: list
    :return: Список файлов с полным путем
    """
    result = []
    pattern = os.sep.join([directory, mask])
    for filename in glob.iglob(pattern, recursive=deep):
        result.append(filename)
    return result


def listdir_os(directory, ext='*', full_path=False):
    """
    Получить все файлы из директории (с полным путем или без)

    :param directory: целевая директория
    :type directory: str
    :param ext: все или с определенным разрешением
    :type ext: str
    :param full_path: с полным путем или нет
    :type full_path: bool

    :rtype: list
    :return: Список файлов (с полным путем или без)
    """
    result = os.listdir(directory)
    if full_path:
        result = []
        for file in os.listdir(directory):
            f_path = ''.join([directory, file])
            result.append(f_path)
    if ext != '*':
        result = list(filter(lambda x: x.endswith(ext), result))
    return result


def dir_get(cur_dir, *args):
    """
    Получить директорию относительно текущей

    :param cur_dir: текущая директория
    :type cur_dir: str
    :param args: набор директорий через запятую
    :type args: str

    :rtype: str
    :return: Полный путь к директории
    """
    cur_dir = cur_dir[:-1]
    return os.sep.join([cur_dir, *args])


def dir_cur(current_file):
    """
    Получить текущую директорию

    :param current_file: __file__
    :type current_file: str

    :rtype: str
    :return: Полный путь к текущей директории
    """
    abs_path = os.path.abspath(current_file)
    f_name = os.path.basename(current_file)
    return abs_path.replace(f_name, '')



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="vpscommacc_core",
    version="1.0.0",
    author="vpscommacc",
    author_email="vps.commacc@yandex.ru",
    description="Набор полезных функций для повседневной работы и уменьшения размера кода",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/vpscommacc",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Natural Language :: Russian",
        "Intended Audience :: Developers",
        "License :: Freely Distributable",
        "Topic :: Utilities",
    ],
    python_requires='>=3.8',
)
